unit Main;

interface

uses
{$IFDEF LINUX}
  SysUtils, Types, Classes, QGraphics, QControls, QForms, QDialogs, QStdCtrls,
  QDBCtrls, QComCtrls, QExtCtrls, QGrids, QDBGrids,
{$ELSE}
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DBCtrls, ExtCtrls, Grids, DBGrids, StdCtrls, ToolWin, ComCtrls, ExtDlgs,
{$ENDIF}
  Db, DBXpress, FMTBcd, SqlExpr, DBClient, Provider;

type
  TfmMain = class(TForm)
    DBGrid1: TDBGrid;
    DBImage: TDBImage;
    ToolBar: TPanel;
    btOpen: TButton;
    btClose: TButton;
    btCreate: TButton;
    btDrop: TButton;
    Splitter1: TSplitter;
    ToolBar1: TToolBar;
    btLoad: TButton;
    btSave: TButton;
    btClear: TButton;
    SQLConnection: TSQLConnection;
    SQLQuery: TSQLQuery;
    DataSource: TDataSource;
    DataSetProvider: TDataSetProvider;
    ClientDataSet: TClientDataSet;
    DBNavigator: TDBNavigator;
    ToolButton1: TToolButton;
    btCancelUpdates: TButton;
    btApplyUpdates: TButton;
    ToolButton2: TToolButton;
    Label1: TLabel;
    edServerName: TEdit;
    Label2: TLabel;
    edDatabase: TEdit;
    procedure btCreateClick(Sender: TObject);
    procedure btDropClick(Sender: TObject);
    procedure btLoadClick(Sender: TObject);
    procedure btSaveClick(Sender: TObject);
    procedure btOpenClick(Sender: TObject);
    procedure btCloseClick(Sender: TObject);
    procedure btClearClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure btApplyUpdatesClick(Sender: TObject);
    procedure btCancelUpdatesClick(Sender: TObject);
    procedure edServerNameExit(Sender: TObject);
    procedure edDatabaseExit(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  fmMain: TfmMain;

implementation

{$R *.dfm}

procedure TfmMain.btCreateClick(Sender: TObject);
begin
  SQLConnection.ExecuteDirect(
    'CREATE TABLE DbxMda_BLOB (' +
    '  uid INT NOT NULL AUTO_INCREMENT PRIMARY KEY,' +
    '  Name VARCHAR(50),' +
    '  Picture LONGBLOB' +
    ')');
end;

procedure TfmMain.btDropClick(Sender: TObject);
begin
  SQLConnection.ExecuteDirect(
    'DROP TABLE DbxMda_BLOB');
end;

procedure TfmMain.btOpenClick(Sender: TObject);
begin
  ClientDataSet.Open;
end;

procedure TfmMain.btCloseClick(Sender: TObject);
begin
  ClientDataSet.Close;
end;

procedure TfmMain.btLoadClick(Sender: TObject);
begin
{$IFDEF LINUX}
  with TOpenDialog.Create(nil) do
{$ELSE}
  with TOpenPictureDialog.Create(nil) do
{$ENDIF}
    try
      InitialDir := '.';
      if ClientDataSet.Active and Execute then begin
        if ClientDataSet.State = dsBrowse then
          ClientDataSet.Edit;

        TBlobField(ClientDataSet.FieldByName('Picture')).LoadFromFile(FileName);
      end;
    finally
      Free;
    end;
end;

procedure TfmMain.btSaveClick(Sender: TObject);
begin
{$IFDEF LINUX}
  with TSaveDialog.Create(nil) do
{$ELSE}
  with TSavePictureDialog.Create(nil) do
{$ENDIF}
    try
      InitialDir := '.';    
      if not ClientDataSet.EOF and Execute then
        TBlobField(ClientDataSet.FieldByName('Picture')).SaveToFile(FileName);
    finally
      Free;
    end;
end;

procedure TfmMain.btClearClick(Sender: TObject);
begin
  if ClientDataSet.State = dsBrowse then
    ClientDataSet.Edit;

  TBlobField(ClientDataSet.FieldByName('Picture')).Clear;
end;

procedure TfmMain.FormShow(Sender: TObject);
begin
  edServerName.Text := SQLConnection.Params.Values['HostName'];
  edDatabase.Text := SQLConnection.Params.Values['Database'];
end;

procedure TfmMain.btApplyUpdatesClick(Sender: TObject);
var
  i: integer;
begin
  i := ClientDataSet.ApplyUpdates(0);
  if i <> 0 then
    raise Exception.Create('Error on ApplyUpdates occured');
end;

procedure TfmMain.btCancelUpdatesClick(Sender: TObject);
begin
  ClientDataSet.CancelUpdates;
end;

procedure TfmMain.edServerNameExit(Sender: TObject);
begin
  SQLConnection.Params.Values['HostName'] := edServerName.Text;
end;

procedure TfmMain.edDatabaseExit(Sender: TObject);
begin
  SQLConnection.Params.Values['Database'] := edDatabase.Text;
end;

procedure TfmMain.FormCreate(Sender: TObject);
begin
{$IFDEF LINUX}
  SQLConnection.LibraryName := {$I ../LibName.inc};
{$ENDIF}
end;

end.
