unit Main;

interface

uses
{$IFDEF LINUX}
  Libc, QDBCtrls, QComCtrls, QStdCtrls, QExtCtrls, QControls, QGrids, QDBGrids,
  QForms,
{$ELSE}
  Windows, DBCtrls, ComCtrls, StdCtrls, ExtCtrls, Controls, Grids, DBGrids,
  Forms,
{$ENDIF}
  SysUtils, Classes, DBXpress, FMTBcd, DBClient, Provider, DB, SqlExpr, DBLocal;

type
  TfmMain = class(TForm)
    DBGrid: TDBGrid;
    DataSource: TDataSource;
    ToolBar: TPanel;
    btOpen: TButton;
    btClose: TButton;
    meSQL: TMemo;
    StatusBar: TStatusBar;
    Panel1: TPanel;
    DBNavigator1: TDBNavigator;
    btRefreshRecord: TButton;
    SQLQuery: TSQLQuery;
    DataSetProvider: TDataSetProvider;
    ClientDataSet: TClientDataSet;
    btApplyUpdates: TButton;
    btCancelUpdates: TButton;
    Label1: TLabel;
    edServerName: TEdit;
    SQLConnection: TSQLConnection;
    Label2: TLabel;
    edDatabase: TEdit;
    btExecute: TButton;
    procedure btOpenClick(Sender: TObject);
    procedure btCloseClick(Sender: TObject);
    procedure btExecuteClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure meSQLExit(Sender: TObject);
    procedure btRefreshRecordClick(Sender: TObject);
    procedure btApplyUpdatesClick(Sender: TObject);
    procedure btCancelUpdatesClick(Sender: TObject);
    procedure ClientDataSetAfterExecute(Sender: TObject;
      var OwnerData: OleVariant);
    procedure edServerNameExit(Sender: TObject);
    procedure edDatabaseExit(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
    procedure ShowState;
  public
    { Public declarations }
  end;

var
  fmMain: TfmMain;

implementation

{$R *.dfm}

procedure TfmMain.ShowState;
var
  St:string;

  procedure AddSt(S:string);
  begin
    if St <> '' then
      St := St + ', ';
    St := St + S;
  end;

begin
  St := '';

  if ClientDataSet.Active then
    AddSt('Active')
  else
    AddSt('Inactive');

  StatusBar.Panels[0].Text := St;
end;

procedure TfmMain.meSQLExit(Sender: TObject);
begin
  if Trim(ClientDataSet.CommandText) <> Trim(meSQL.Lines.Text) then
    ClientDataSet.CommandText := meSQL.Lines.Text;
  ShowState;
end;

procedure TfmMain.btOpenClick(Sender: TObject);
begin
  try
    meSQLExit(nil);
    SQLQuery.NoMetadata := False;
    ClientDataSet.Open;
  finally
    ShowState;
  end;
end;

procedure TfmMain.btCloseClick(Sender: TObject);
begin
  ClientDataSet.Close;
  ShowState;              
end;

procedure TfmMain.btExecuteClick(Sender: TObject);
begin
  try
    ClientDataSet.Execute;
  finally
    ShowState;
  end;
end;

procedure TfmMain.FormShow(Sender: TObject);
begin
  edServerName.Text := SQLConnection.Params.Values['HostName'];
  edDatabase.Text := SQLConnection.Params.Values['Database'];
  ClientDataSet.CommandText := meSQL.Lines.Text;
  ShowState;
end;

procedure TfmMain.btRefreshRecordClick(Sender: TObject);
begin
  ClientDataSet.RefreshRecord;
end;

procedure TfmMain.btApplyUpdatesClick(Sender: TObject);
var
  i: integer;
begin
  i := ClientDataSet.ApplyUpdates(0);
  if i <> 0 then
    raise Exception.Create('Error on ApplyUpdates occured');
end;

procedure TfmMain.btCancelUpdatesClick(Sender: TObject);
begin
  ClientDataSet.CancelUpdates;
end;

procedure TfmMain.ClientDataSetAfterExecute(Sender: TObject;
  var OwnerData: OleVariant);
begin
  ShowState;

{$IFDEF WIN32}
  MessageBeep(1);
{$ENDIF}
end;

procedure TfmMain.edServerNameExit(Sender: TObject);
begin
  SQLConnection.Params.Values['HostName'] := edServerName.Text;
end;

procedure TfmMain.edDatabaseExit(Sender: TObject);
begin
  SQLConnection.Params.Values['Database'] := edDatabase.Text;
end;

procedure TfmMain.FormCreate(Sender: TObject);
begin
{$IFDEF LINUX}
  SQLConnection.LibraryName := {$I ../LibName.inc};
{$ENDIF}
end;

end.

